import { 
  ShoppingBag, 
  Users, 
  Globe2, 
  Heart, 
  Phone, 
  Mail, 
  MapPin,
  ArrowUp 
} from 'lucide-react';

// Import at the top of your file
import { scrollToElementById, scrollToTop } from './utils/scrollUtils';

// Define the Product interface
interface Product {
  id: string | number;
  title: string;
  description: string;
  price: string;
  image: string;
  cause: string;
  // Add any other properties your products have
}

import { products } from './data/products';

import { useState, useEffect, Suspense, lazy } from 'react';
import { Routes, Route, Link, useNavigate } from 'react-router-dom';
import { BeadAnimation } from './components/BeadAnimation';

// Lazy load components for code splitting
const Products = lazy(() => import('./pages/Products'));
const ProductDetail = lazy(() => import('./pages/ProductDetail'));
const MoreInfo = lazy(() => import('./pages/MoreInfo'));
const Checkout = lazy(() => import('./pages/Checkout'));
const Legal = lazy(() => import('./pages/Legal'));
import { CartButton } from './components/CartButton';

// Import CartProvider and useCart
import { CartProvider, useCart } from './context/CartContext';

import { SpinningIconAnimation } from './components/SpinningIconAnimation';

// Replace your existing scrollToSection with:
const scrollToSection = (id: string, duration = 800) => {
  scrollToElementById(id, duration);
};

// Update your navigation functions
const handleNavToSection = (id: string, duration = 800) => {
  // Check if we're already on the homepage
  if (window.location.pathname !== '/') {
    // If not on homepage, store the section ID to navigate to after redirect
    localStorage.setItem('scrollToSection', id);
    localStorage.setItem('scrollDuration', String(duration));
    // Redirect to homepage
    window.location.href = '/';
  } else {
    // Already on homepage, just scroll
    scrollToSection(id, duration);
  }
};

// Back to Top Button Component
function BackToTopButton() {
  const [isVisible, setIsVisible] = useState(false);

  const toggleVisibility = () => {
    setIsVisible(window.pageYOffset > 300);
  };

  useEffect(() => {
    window.addEventListener('scroll', toggleVisibility);
    return () => window.removeEventListener('scroll', toggleVisibility);
  }, []);

  return (
    <button
      onClick={() => scrollToTop(1500)}
      className={`fixed bottom-6 right-20 bg-purple-600 text-white p-3 rounded-full shadow-lg hover:bg-purple-700 transition-all z-50 ${
        isVisible
          ? 'opacity-100 translate-y-0'
          : 'opacity-0 translate-y-10 pointer-events-none'
      }`}
      aria-label="Back to top"
    >
      <ArrowUp className="w-6 h-6" />
    </button>
  );
}

// Update the Footer component to accept the handleShopClick function
function Footer({ handleShopClick }: { handleShopClick: () => void }) {
  return (
    <footer className="bg-gray-900 text-white py-10 px-4">
      <div className="max-w-6xl mx-auto">
        <div className="grid grid-cols-1 md:grid-cols-3 gap-10 mb-8">
          <div>
            <h3 className="text-xl font-semibold mb-4">Thakara Bracelets</h3>
            <p className="text-gray-300 mb-4">
              Premium handcrafted jewelry featuring exceptional artisan quality and traditional craftsmanship techniques.
            </p>
            <div className="flex space-x-4">
              <a href="https://instagram.com" className="text-gray-300 hover:text-white">
                <span className="sr-only">Instagram</span>
                <svg className="h-6 w-6" fill="currentColor" viewBox="0 0 24 24">
                  <path fillRule="evenodd" d="M12.315 2c2.43 0 2.784.013 3.808.06 1.064.049 1.791.218 2.427.465.668.25 1.346.637 1.954 1.246.61.609.997 1.286 1.248 1.954.247.636.416 1.363.465 2.427.047 1.024.06 1.379.06 3.808s-.013 2.784-.06 3.808c-.049 1.064-.218 1.791-.465 2.427a5.318 5.318 0 01-1.248 1.954 5.338 5.338 0 01-1.954 1.246c-.636.247-1.363.416-2.427.465-1.024.047-1.379.06-3.808.06-2.43 0-2.784-.013-3.808-.06-1.064-.049-1.791-.218-2.427-.465a5.339 5.339 0 01-1.954-1.246 5.317 5.317 0 01-1.246-1.954c-.247-.636-.416-1.363-.465-2.427-.047-1.024-.06-1.379-.06-3.808s.013-2.784.06-3.808c.049-1.064.218-1.791.465-2.427a5.318 5.318 0 011.246-1.954 5.338 5.338 0 011.954-1.246c.636-.247 1.363-.416 2.427-.465 1.024-.047 1.379-.06 3.808-.06z" clipRule="evenodd"></path>
                </svg>
              </a>
              <a href="https://twitter.com" className="text-gray-300 hover:text-white">
                <span className="sr-only">Twitter</span>
                <svg className="h-6 w-6" fill="currentColor" viewBox="0 0 24 24">
                  <path d="M8.29 20.251c7.547 0 11.675-6.253 11.675-11.675 0-.178 0-.355-.012-.53A8.348 8.348 0 0022 5.92a8.19 8.19 0 01-2.357.646 4.118 4.118 0 001.804-2.27 8.224 8.224 0 01-2.605.996 4.107 4.107 0 00-6.993 3.743 11.65 11.65 0 01-8.457-4.287 4.106 4.106 0 001.27 5.477A4.072 4.072 0 012.8 9.713v.052a4.105 4.105 0 003.292 4.022 4.095 4.095 0 01-1.853.07 4.108 4.108 0 003.834 2.85A8.233 8.233 0 012 18.407a11.616 11.616 0 006.29 1.84"></path>
                </svg>
              </a>
              <a href="https://facebook.com" className="text-gray-300 hover:text-white">
                <span className="sr-only">Facebook</span>
                <svg className="h-6 w-6" fill="currentColor" viewBox="0 0 24 24">
                  <path fillRule="evenodd" d="M22 12c0-5.523-4.477-10-10-10S2 6.477 2 12c0 4.991 3.657 9.128 8.438 9.878v-6.987h-2.54V12h2.54V9.797c0-2.506 1.492-3.89 3.777-3.89 1.094 0 2.238.195 2.238.195v2.46h-1.26c-1.243 0-1.63.771-1.63 1.562V12h2.773l-.443 2.89h-2.33v6.988C18.343 21.128 22 16.991 22 12z" clipRule="evenodd"></path>
                </svg>
              </a>
            </div>
          </div>
          <div>
            <h3 className="text-xl font-semibold mb-4">Quick Links</h3>
            <ul className="space-y-2">
              <li>
                <Link to="/" className="text-gray-300 hover:text-white">Home</Link>
              </li>
              <li>
                <button 
                  onClick={handleShopClick}
                  className="text-gray-300 hover:text-white bg-transparent border-0 p-0 cursor-pointer"
                >
                  Shop
                </button>
              </li>
              {/* Update Custom Orders link in footer */}
              <li>
                <Link 
                  to="/more-info#custom-orders" 
                  className="text-gray-300 hover:text-white"
                  onClick={(e) => {
                    // If already on more-info page, handle smooth scroll
                    if (window.location.pathname === '/more-info') {
                      e.preventDefault();
                      scrollToElementById('custom-orders', 800);
                    }
                  }}
                >
                  Custom Orders
                </Link>
              </li>
              <li>
                <Link to="/more-info" className="text-gray-300 hover:text-white">More Information</Link>
              </li>
              <li>
                <a 
                  href="#about" 
                  className="text-gray-300 hover:text-white" 
                  onClick={(e) => {
                    e.preventDefault();
                    handleNavToSection('about', 800);
                  }}
                >
                  About Us
                </a>
              </li>
              <li>
                <a 
                  href="#contact" 
                  className="text-gray-300 hover:text-white" 
                  onClick={(e) => {
                    e.preventDefault();
                    handleNavToSection('contact', 2500);
                  }}
                >
                  Contact
                </a>
              </li>
            </ul>
          </div>
          <div>
            <h3 className="text-xl font-semibold mb-4">Newsletter</h3>
            <p className="text-gray-300 mb-4">
              Stay updated on our latest products and craftsmanship stories.
            </p>
            <div className="flex">
              <input 
                type="email" 
                placeholder="Your email" 
                className="px-4 py-2 w-full rounded-l-md focus:outline-none text-gray-900"
              />
              <button className="bg-purple-600 hover:bg-purple-700 px-4 py-2 rounded-r-md">
                Subscribe
              </button>
            </div>
          </div>
        </div>
        <div className="pt-8 mt-8 border-t border-gray-700 text-center md:flex md:justify-between text-gray-400 text-sm">
          <p>© 2025 Thakara Bracelets. All rights reserved.</p>
          <div className="mt-4 md:mt-0 space-x-4">
            <Link to="/legal#privacy" className="hover:text-white">Privacy Policy</Link>
            <Link to="/legal#terms" className="hover:text-white">Terms of Service</Link>
            <Link to="/more-info" className="hover:text-white">Learn More About Our Craftsmanship</Link>
          </div>
        </div>
      </div>
    </footer>
  );
}

import {
  trackEvent,
  trackPageView,
  trackViewItemList,
  trackSelectItem,
  trackViewItem,
  trackAddToCart,
  trackSignUp,
  trackContact,
  trackGenerateLead
} from './utils/analytics';

function App() {
  const [playBeadAnimation, setPlayBeadAnimation] = useState(false);
  const navigate = useNavigate();
  const location = window.location;

  useEffect(() => {
    // Track page view on initial load and on route change
    trackPageView(location.pathname + location.search);
    // Optionally, listen to route changes if using react-router v6+ with useLocation
    // (not shown here for brevity)
  }, [location.pathname, location.search]);
  
  const onAnimationComplete = () => {
    setPlayBeadAnimation(false);
  };
  
  const handleShopClick = () => {
    // Start the bead animation first
    setPlayBeadAnimation(true);
    
    // Scroll to top first with callback on completion
    scrollToTop(1200);
    
    // Use setTimeout to give the scroll time to complete
    setTimeout(() => {
      navigate('/products');
    }, 1300);
  };
  
  return (
    <CartProvider>
      {/* BeadAnimation at app level */}
      <BeadAnimation 
        isAnimating={playBeadAnimation}  // Changed from isPlaying
        onAnimationEnd={onAnimationComplete}  // Changed from onComplete
      />
      
      {/* Pass the animation function to AppContent */}
      <AppContent triggerBeadAnimation={handleShopClick} />
    </CartProvider>
  );
}

// Update AppContent to receive and use the animation trigger
function AppContent({ triggerBeadAnimation }: { triggerBeadAnimation: () => void }) {
  const [mobileMenuOpen, setMobileMenuOpen] = useState(false);
  const navigate = useNavigate();
  const { spinAnimations, removeSpinAnimation } = useCart();

  const toggleMobileMenu = () => {
    setMobileMenuOpen(!mobileMenuOpen);
  };

  // Close mobile menu when clicking on a navigation item
  const handleNavClick = (id?: string) => {
    setMobileMenuOpen(false);
    if (id) {
      const duration = id === 'contact' ? 2500 : 800;
      handleNavToSection(id, duration);
    }
  };

  const handleShopClick = () => {
    triggerBeadAnimation();
    setMobileMenuOpen(false);
  };

  return (
    <div className="min-h-screen bg-white flex flex-col">
      <nav className="bg-purple-800 shadow-md fixed w-full z-50">
        <div className="max-w-6xl mx-auto px-4">
          <div className="flex justify-between items-center h-16">
            <Link
              to="/"
              className="font-bold text-xl text-white transition-all duration-100 hover:tracking-wide z-10"
              onClick={() => {
                window.scrollTo({
                  top: 0,
                  behavior: 'smooth'
                });
              }}
            >
              Thakara Bracelets
            </Link>

            {/* Mobile menu button */}
            <button 
              className="md:hidden text-white focus:outline-none z-10"
              onClick={toggleMobileMenu}
              aria-label="Toggle navigation menu"
            >
              {mobileMenuOpen ? (
                <svg className="h-6 w-6" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M6 18L18 6M6 6l12 12" />
                </svg>
              ) : (
                <svg className="h-6 w-6" fill="none" viewBox="0 0 24 24" stroke="currentColor">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M4 6h16M4 12h16M4 18h16" />
                </svg>
              )}
            </button>

            {/* Desktop Navigation Menu */}
            <div className="hidden md:flex space-x-8">
              <button
                onClick={handleShopClick}
                className="text-white hover:font-bold transition-all duration-100 hover:tracking-wide"
              >
                Shop
              </button>

              <button
                onClick={() => handleNavToSection('about', 800)}
                className="text-white hover:text-purple-200 font-normal bg-transparent border-0 cursor-pointer hover:font-bold transition-all duration-100 hover:tracking-wide"
              >
                About
              </button>

              <Link
                to="/more-info"
                className="text-white hover:font-bold transition-all duration-100 hover:tracking-wide"
              >
                More Info
              </Link>

              {/* Update Custom Orders link in desktop nav */}
              <Link
                to="/more-info#custom-orders"
                className="text-white hover:font-bold transition-all duration-100 hover:tracking-wide"
                onClick={(e) => {
                  // If already on the more-info page, handle smooth scroll
                  if (window.location.pathname === '/more-info') {
                    e.preventDefault();
                    scrollToElementById('custom-orders', 800);
                  }
                }}
              >
                Custom Orders
              </Link>

              <button
                onClick={() => handleNavToSection('contact', 2500)}
                className="text-white hover:text-purple-200 font-normal bg-transparent border-0 cursor-pointer hover:font-bold transition-all duration-500"
              >
                Contact
              </button>
            </div>
          </div>
        </div>

        {/* Mobile Navigation Menu */}
        <div className={`absolute top-0 left-0 w-full bg-purple-800 shadow-lg transition-all duration-300 ease-in-out transform md:hidden ${
          mobileMenuOpen ? 'opacity-100 translate-y-16' : 'opacity-0 -translate-y-full pointer-events-none'
        }`}>
          <div className="px-4 py-6 space-y-4 flex flex-col items-center">
            <button
              onClick={() => {
                setMobileMenuOpen(false);
                handleShopClick();
              }}
              className="text-white hover:text-purple-200 w-full text-center py-2 hover:font-bold"
            >
              Shop
            </button>

            <button
              onClick={() => handleNavClick('about')}
              className="text-white hover:text-purple-200 font-normal bg-transparent border-0 cursor-pointer w-full text-center py-2 hover:font-bold"
            >
              About
            </button>

            <Link
              to="/more-info"
              className="text-white hover:text-purple-200 w-full text-center py-2 hover:font-bold"
              onClick={() => handleNavClick()}
            >
              More Info
            </Link>

            {/* Update Custom Orders link in mobile nav */}
            <Link
              to="/more-info#custom-orders"
              className="text-white hover:text-purple-200 w-full text-center py-2 hover:font-bold"
              onClick={(e) => {
                setMobileMenuOpen(false);
                // If already on the more-info page, handle smooth scroll
                if (window.location.pathname === '/more-info') {
                  e.preventDefault();
                  scrollToElementById('custom-orders', 800);
                }
              }}
            >
              Custom Orders
            </Link>

            <button
              onClick={() => handleNavClick('contact')} // This will use the 2500ms from the handler
              className="text-white hover:text-purple-200 font-normal bg-transparent border-0 cursor-pointer w-full text-center py-2 hover:font-bold transition-all duration-500"
            >
              Contact
            </button>
          </div>
        </div>
      </nav>

      <div className="flex-grow">
        <Suspense fallback={
          <div className="pt-24 px-4">
            <div className="max-w-6xl mx-auto text-center py-20">
              <div className="animate-spin rounded-full h-12 w-12 border-b-2 border-purple-600 mx-auto"></div>
              <p className="mt-4 text-gray-600">Loading...</p>
            </div>
          </div>
        }>
          <Routes>
            <Route path="/" element={<HomePage handleShopClick={handleShopClick} />} />
            <Route path="/products" element={<Products />} />
            <Route path="/products/:id" element={<ProductDetail />} />
            <Route path="/more-info" element={<MoreInfo />} />
            <Route path="/checkout" element={<Checkout />} />
            <Route path="/legal" element={<Legal />} />
          </Routes>
        </Suspense>
      </div>

      <Footer handleShopClick={handleShopClick} />

      <CartButton />
      <BackToTopButton />

      {/* Render spinning icon animations */}
      {spinAnimations && spinAnimations.map(animation => (
        <SpinningIconAnimation
          key={animation.id}
          startPosition={animation.startPosition}
          onComplete={() => removeSpinAnimation(animation.id)}
        />
      ))}
    </div>
  );
}

// Define HomePage with reordered sections
function HomePage({ handleShopClick }: { handleShopClick: () => void }) {
  const { addToCart } = useCart();

  useEffect(() => {
    const sectionToScrollTo = localStorage.getItem('scrollToSection');
    const duration = localStorage.getItem('scrollDuration');
    
    if (sectionToScrollTo) {
      // Small delay to ensure the page is fully loaded
      setTimeout(() => {
        scrollToSection(sectionToScrollTo, duration ? parseInt(duration) : 800);
        // Clear the storage after navigation
        localStorage.removeItem('scrollToSection');
        localStorage.removeItem('scrollDuration');
      }, 100);
    }
  }, []);

  // Use the first 3 products as featured products
  const featuredProducts = products.slice(0, 3);

  // Track featured product impressions
  useEffect(() => {
    trackViewItemList(featuredProducts, 'Featured Collections');
  }, [featuredProducts]);

  return (
    <>
      {/* Hero Section */}
      <header className="relative h-[80vh] bg-cover bg-center" style={{
        backgroundImage: 'url("https://images.unsplash.com/photo-1615873968403-89e068629265?auto=format&fit=crop&q=80&w=2532")',
      }}>
        <div className="absolute inset-0 flex items-center justify-center">
          <div className="text-center text-white px-4">
            <h1 className="text-5xl text-green md:text-7xl font-bold mb-6">Artisan-Made Jewelry Collection</h1>
            <p className="text-xl md:text-3xl max-w-4xl mx-auto mb-8 text-white-900 font-bold bg-black bg-opacity-30 rounded-lg p-0.3">
              Premium handcrafted bracelets & rosaries featuring exceptional quality and traditional craftsmanship
            </p>
            <button
              onClick={handleShopClick}
              className="bg-purple-600 text-white px-8 py-3 rounded-md text-lg font-semibold hover:bg-purple-700 transition-colors inline-block"
            >
              Shop Our Collection
            </button>
          </div>
        </div>
      </header>

      {/* How It Works Section */}
      <section className="py-12 px-4 bg-purple-800 text-white">
        <div className="max-w-4xl mx-auto">
          <div className="text-center mb-8">
            <h2 className="text-2xl md:text-3xl font-bold mb-3 text-white">Our Process</h2>
            <p className="text-purple-100 max-w-xl mx-auto text-sm">
              Quality craftsmanship delivered with professional excellence
            </p>
          </div>
          
          <div className="grid grid-cols-2 md:grid-cols-4 gap-6">
            <div className="text-center">
              <div className="w-12 h-12 bg-purple-600 rounded-full flex items-center justify-center mx-auto mb-3">
                <ShoppingBag className="w-6 h-6 text-white" />
              </div>
              <h3 className="text-lg font-semibold mb-1 text-white">Order</h3>
              <p className="text-purple-100 text-sm">
                Browse & select
              </p>
            </div>
            
            <div className="text-center">
              <div className="w-12 h-12 bg-purple-600 rounded-full flex items-center justify-center mx-auto mb-3">
                <Users className="w-6 h-6 text-white" />
              </div>
              <h3 className="text-lg font-semibold mb-1 text-white">Craft</h3>
              <p className="text-purple-100 text-sm">
                Expert handcraft
              </p>
            </div>
            
            <div className="text-center">
              <div className="w-12 h-12 bg-purple-600 rounded-full flex items-center justify-center mx-auto mb-3">
                <Globe2 className="w-6 h-6 text-white" />
              </div>
              <h3 className="text-lg font-semibold mb-1 text-white">Inspect</h3>
              <p className="text-purple-100 text-sm">
                Quality assured
              </p>
            </div>
            
            <div className="text-center">
              <div className="w-12 h-12 bg-purple-600 rounded-full flex items-center justify-center mx-auto mb-3">
                <Heart className="w-6 h-6 text-white" />
              </div>
              <h3 className="text-lg font-semibold mb-1 text-white">Deliver</h3>
              <p className="text-purple-100 text-sm">
                With care
              </p>
            </div>
          </div>
        </div>
      </section>

      {/* Featured Collections Section */}
      <section className="py-20 px-4">
        <div className="max-w-6xl mx-auto">
          <div className="text-center mb-16">
            <h2 className="text-3xl md:text-4xl font-bold mb-4">Featured Collections</h2>
            <p className="text-gray-600 max-w-2xl mx-auto">
              Each piece represents exceptional craftsmanship, showcasing traditional techniques and premium materials
            </p>
          </div>
          <div className="grid md:grid-cols-3 gap-8">
            {featuredProducts.map((product: Product) => (
              <div key={product.id} className="group relative">
                <Link to={`/products/${product.id}`}
                  onClick={() => trackSelectItem(product, 'Featured Collections')}
                >
                  <div className="aspect-square overflow-hidden rounded-lg bg-gray-100">
                    <img
                      src={product.image}
                      alt={product.title}
                      className="h-full w-full object-cover object-center group-hover:opacity-75 transition-opacity duration-300"
                    />
                  </div>
                </Link>
                <div className="mt-4 flex justify-between">
                  <div>
                    <Link to={`/products/${product.id}`}>
                      <h3 className="text-lg font-semibold text-gray-900 hover:text-purple-600">{product.title}</h3>
                    </Link>
                    <p className="mt-1 text-sm text-gray-500">{product.cause}</p>
                  </div>
                  <p className="text-lg font-medium text-gray-900">{product.price}</p>
                </div>
                <button
                  onClick={() => {
                    addToCart(product);
                    trackAddToCart(product);
                  }}
                  className="mt-4 w-full bg-purple-600 text-white py-2 px-4 rounded-md hover:bg-purple-700 transition-colors flex items-center justify-center gap-2"
                >
                  <ShoppingBag className="w-5 h-5" />
                  Add to Cart
                </button>
              </div>
            ))}
          </div>
        </div>
      </section>

      {/* Artisan Excellence Explanation */}
      <section className="py-12 px-4 bg-purple-900 text-white">
        <div className="max-w-4xl mx-auto">
          <div className="text-center mb-8">
            <h2 className="text-2xl md:text-3xl font-bold mb-3 text-white">Exceptional Artisan Quality</h2>
            <p className="text-purple-100 max-w-xl mx-auto text-sm">
              Premium materials, traditional techniques, certified excellence
            </p>
          </div>
          
          <div className="grid md:grid-cols-3 gap-6">
            <div className="text-center">
              <div className="w-12 h-12 bg-purple-600 rounded-full flex items-center justify-center mx-auto mb-3">
                <span className="text-white font-bold">✓</span>
              </div>
              <h3 className="text-lg font-semibold mb-1 text-white">Quality</h3>
              <p className="text-purple-100 text-sm">
                Inspected & certified
              </p>
            </div>
            
            <div className="text-center">
              <div className="w-12 h-12 bg-purple-600 rounded-full flex items-center justify-center mx-auto mb-3">
                <span className="text-white font-bold">⚡</span>
              </div>
              <h3 className="text-lg font-semibold mb-1 text-white">Artisan</h3>
              <p className="text-purple-100 text-sm">
                Fair wages & skills
              </p>
            </div>
            
            <div className="text-center">
              <div className="w-12 h-12 bg-purple-600 rounded-full flex items-center justify-center mx-auto mb-3">
                <span className="text-white font-bold">◆</span>
              </div>
              <h3 className="text-lg font-semibold mb-1 text-white">Materials</h3>
              <p className="text-purple-100 text-sm">
                Premium & authentic
              </p>
            </div>
          </div>
        </div>
      </section>

      {/* Business Metrics Section */}
      <section className="py-12 px-4 bg-purple-50">
        <div className="max-w-6xl mx-auto">
          <div className="text-center mb-8">
            <h2 className="text-2xl md:text-3xl font-bold mb-2">Our Craftsmanship by Numbers</h2>
            <p className="text-gray-600">Quality metrics that showcase our commitment to excellence</p>
          </div>
          
          <div className="grid md:grid-cols-3 gap-8">
            <div className="bg-white p-8 rounded-lg shadow-md text-center">
              <div className="text-4xl font-bold text-purple-600 mb-2">500+</div>
              <p className="text-lg">Pieces Handcrafted</p>
            </div>
            <div className="bg-white p-8 rounded-lg shadow-md text-center">
              <div className="text-4xl font-bold text-purple-600 mb-2">24</div>
              <p className="text-lg">Master Artisans</p>
            </div>
            <div className="bg-white p-8 rounded-lg shadow-md text-center">
              <div className="text-4xl font-bold text-purple-600 mb-2">15+</div>
              <p className="text-lg">Years of Experience</p>
            </div>
          </div>
        </div>
      </section>

      {/* Artisan Stories Section */}
      <section className="py-20 px-4 bg-gray-50">
        <div className="max-w-6xl mx-auto">
          <div className="text-center mb-16">
            <h2 className="text-3xl md:text-4xl font-bold mb-4">Meet Our Artisans</h2>
            <p className="text-gray-600 max-w-3xl mx-auto">
              Behind every bracelet is a skilled artisan with a unique story and craft tradition
            </p>
          </div>
          
          <div className="grid md:grid-cols-2 gap-8">
            <div className="bg-white rounded-lg shadow-md overflow-hidden">
              <div className="aspect-w-16 aspect-h-9">
                <img 
                  src="/People/Amara.png" 
                  alt="Amara - Artisan crafting beaded jewelry" 
                  className="w-full h-64 object-cover object-center"
                />
              </div>
              <div className="p-6">
                <h3 className="text-xl font-semibold mb-2">Amara's Story</h3>
                <p className="text-gray-600 mb-4">
                  "Working with Thakara has allowed me to support my family while preserving 
                  the traditional beading techniques passed down from my grandmother. Each bead I work 
                  with carries a piece of our heritage."
                </p>
                <div className="flex items-center text-sm text-gray-500">
                  <MapPin className="w-4 h-4 mr-1" />
                  <span>Machakos, Kenya</span>
                </div>
              </div>
            </div>
            
            <div className="bg-white rounded-lg shadow-md overflow-hidden">
              <div className="aspect-w-16 aspect-h-9">
                <img 
                  src="/People/Joseph.png" 
                  alt="Joseph - Artisan creating handmade jewelry" 
                  className="w-full h-64 object-cover object-center"
                />
              </div>
              <div className="p-6">
                <h3 className="text-xl font-semibold mb-2">Joseph's Journey</h3>
                <p className="text-gray-600 mb-4">
                  "I started collecting plastic waste from our beaches to protect our ocean. Now I transform 
                  what was once trash into beautiful, meaningful pieces that tell the story of our 
                  community's commitment to the environment."
                </p>
                <div className="flex items-center text-sm text-gray-500">
                  <MapPin className="w-4 h-4 mr-1" />
                  <span>Mombasa, Kenya</span>
                </div>
              </div>
            </div>
          </div>
        </div>
      </section>

      <section id="about" className="py-20 px-4 bg-gradient-to-br from-gray-900 via-gray-800 to-gray-700 text-white">
        <div className="max-w-6xl mx-auto">
          <div className="text-center mb-16">
            <h2 className="text-3xl md:text-4xl font-bold mb-4 text-white">About Thakara Bracelets</h2>
            <p className="text-gray-300 max-w-3xl mx-auto">
              Founded with a passion for both beautiful craftsmanship and positive social impact, Thakara Bracelets bridges the gap between artisanal traditions and global change.
            </p>
          </div>
          
          <div className="grid md:grid-cols-2 gap-12 items-center">
            <div>
              <img 
                src="/Icons/RvwThkr.png" 
                alt="Artisan crafting beaded jewelry" 
                className="rounded-lg shadow-lg w-full h-auto"
              />
            </div>
            <div className="space-y-6">
              <div>
                <h3 className="text-2xl font-semibold mb-3 text-white">Our Story</h3>
                <p className="text-gray-300">
                  Thakara Bracelets was born from a simple vision: creating stunning jewelry that makes a meaningful difference. We work directly with skilled artisans from communities around the world, ensuring fair wages and sustainable practices.
                </p>
              </div>
              <div>
                <h3 className="text-2xl font-semibold mb-3 text-white">Our Mission</h3>
                <p className="text-gray-300">
                  We're committed to creating economic opportunities, preserving traditional craft techniques, and promoting environmental sustainability through our products and practices.
                </p>
              </div>
              <div>
                <h3 className="text-2xl font-semibold mb-3 text-white">Our Commitment</h3>
                <p className="text-gray-300">
                  Every bracelet represents our commitment to transparency, sustainability, and positive impact. From production to packaging, we strive to make choices that benefit both people and planet.
                </p>
              </div>
            </div>
          </div>
        </div>
      </section>

      <section id="contact" className="py-20 px-4 bg-gray-900 text-white">
        <div className="max-w-6xl mx-auto">
          <div className="text-center mb-16">
            <h2 className="text-3xl md:text-4xl font-bold mb-4">Get in Touch</h2>
            <p className="text-gray-300 max-w-2xl mx-auto">
              Have questions about our products or impact? We'd love to hear from you.
            </p>
          </div>
          <div className="grid md:grid-cols-3 gap-8">
            <div className="text-center">
              <Phone className="w-8 h-8 text-purple-400 mx-auto mb-4" />
              <h3 className="text-xl font-semibold mb-2">Call Us</h3>
              <p className="text-gray-200">
                <a href="tel:+254748710326" onClick={() => trackContact('phone')}>+254 748710326</a>
              </p>
            </div>
            <div className="text-center">
              <Mail className="w-8 h-8 text-purple-400 mx-auto mb-4" />
              <h3 className="text-xl font-semibold mb-2">Email Us</h3>
              <p className="text-gray-200">
                <a href="mailto:briansbrianaddress@gmail.com" onClick={() => trackContact('email')}>briansbrianaddress@gmail.com</a>
              </p>
            </div>
            <div className="text-center">
              <MapPin className="w-8 h-8 text-purple-400 mx-auto mb-4" />
              <h3 className="text-xl font-semibold mb-2">Visit Us</h3>
              <p className="text-gray-200">Machakos, Kenya</p>
            </div>
          </div>
        </div>
      </section>

      <section className="py-20 px-4 bg-purple-800 text-white">
        <div className="max-w-6xl mx-auto">
          <div className="text-center mb-16">
            <h2 className="text-3xl md:text-4xl font-bold mb-4">Partner With Excellence</h2>
            <p className="text-purple-100 max-w-3xl mx-auto">
              Join our network of retailers, distributors, and brand ambassadors to bring authentic artisan jewelry to more customers worldwide
            </p>
          </div>

          <div className="grid md:grid-cols-3 gap-8">
            <div className="bg-purple-700 p-8 rounded-lg text-center">
              <div className="bg-purple-600 w-16 h-16 rounded-full flex items-center justify-center mx-auto mb-6">
                <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor" className="w-8 h-8">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M19 21V5a2 2 0 00-2-2H7a2 2 0 00-2 2v16m14 0h2m-2 0h-5m-9 0H3m2 0h5M9 7h1m-1 4h1m4-4h1m-1 4h1m-5 10v-5a1 1 0 011-1h2a1 1 0 011 1v5m-4 0h4" />
                </svg>
              </div>
              <h3 className="text-xl font-semibold mb-4">Retail Partners</h3>
              <p className="text-purple-100 mb-6">
                Expand your jewelry collection with our authentic, handcrafted pieces. Wholesale pricing and marketing support available.
              </p>
              <Link 
                to="/more-info#wholesale" 
                className="inline-block bg-purple-600 hover:bg-purple-900 text-white py-2 px-4 rounded-md transition-colors"
                onClick={() => trackGenerateLead('wholesale')}
              >
                Wholesale Opportunities
              </Link>
            </div>

            <div className="bg-purple-700 p-8 rounded-lg text-center">
              <div className="bg-purple-600 w-16 h-16 rounded-full flex items-center justify-center mx-auto mb-6">
                <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor" className="w-8 h-8">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M3 6l3 1m0 0l-3 9a5.002 5.002 0 006.001 0M6 7l3 9M6 7l6-2m6 2l3-1m-3 1l-3 9a5.002 5.002 0 006.001 0M18 7l3 9m-3-9l-6-2m0-2v2m0 16V5m0 16H9m3 0h3" />
                </svg>
              </div>
              <h3 className="text-xl font-semibold mb-4">Distribution Partners</h3>
              <p className="text-purple-100 mb-6">
                We seek reliable distributors to help us reach new markets while maintaining our quality standards and artisan relationships.
              </p>
              <Link 
                to="/more-info#distribution" 
                className="inline-block bg-purple-600 hover:bg-purple-900 text-white py-2 px-4 rounded-md transition-colors"
                onClick={() => trackGenerateLead('distribution')}
              >
                Distribution Inquiries
              </Link>
            </div>

            <div className="bg-purple-700 p-8 rounded-lg text-center">
              <div className="bg-purple-600 w-16 h-16 rounded-full flex items-center justify-center mx-auto mb-6">
                <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke="currentColor" className="w-8 h-8">
                  <path strokeLinecap="round" strokeLinejoin="round" strokeWidth={2} d="M12 4.354a4 4 0 110 5.292M15 21H3v-1a6 6 0 0112 0v1zm0 0h6v-1a6 6 0 00-9-5.197M13 7a4 4 0 11-8 0 4 4 0 018 0z" />
                </svg>
              </div>
              <h3 className="text-xl font-semibold mb-4">Brand Ambassadors</h3>
              <p className="text-purple-100 mb-6">
                Love our jewelry? Join our ambassador program to earn commissions while sharing authentic artisan craftsmanship.
              </p>
              <Link 
                to="/more-info#ambassadors" 
                className="inline-block bg-purple-600 hover:bg-purple-900 text-white py-2 px-4 rounded-md transition-colors"
                onClick={() => trackGenerateLead('ambassador')}
              >
                Become an Ambassador
              </Link>
            </div>
          </div>
        </div>
      </section>
    </>
  );
}

export default App;